@@ -61,10 +61,11 @@ class Compressor(object):
 
         return js
 
-    def compress_css(self, paths, variant=None, asset_url=None, **kwargs):
+    def compress_css(self, paths, variant=None, asset_url=None,
+                     absolute_asset_paths=True, **kwargs):
         """Concatenate and compress CSS files"""
-        css = self.concatenate_and_rewrite(paths, variant)
-
+        css = self.concatenate_and_rewrite(paths, variant,
+                                           absolute_asset_paths)
         compressor = self.css_compressor
         if compressor:
             css = getattr(compressor(verbose=self.verbose), 'compress_css')(css)
@@ -101,7 +102,7 @@ class Compressor(object):
 
     def base_path(self, paths):
         def names_equal(name):
-            return all(n==name[0] for n in name[1:])
+            return all(n == name[0] for n in name[1:])
         directory_levels = zip(*[p.split(os.sep) for p in paths])
         return os.sep.join(x[0] for x in takewhile(names_equal, directory_levels))
 
@@ -116,7 +117,8 @@ class Compressor(object):
         ), r"\1", path)
         return re.sub(r"[\/\\]", "_", name)
 
-    def concatenate_and_rewrite(self, paths, variant=None):
+    def concatenate_and_rewrite(self, paths, variant=None,
+                                absolute_asset_paths=True):
         """Concatenate together files and rewrite urls"""
         stylesheets = []
         for path in paths:
@@ -124,7 +126,8 @@ class Compressor(object):
                 asset_path = match.group(1)
                 if asset_path.startswith("http") or asset_path.startswith("//"):
                     return "url(%s)" % asset_path
-                asset_url = self.construct_asset_path(asset_path, path, variant)
+                asset_url = self.construct_asset_path(asset_path, path, variant,
+                                                      absolute_asset_paths)
                 return "url(%s)" % asset_url
             content = self.read_file(path)
             content = re.sub(URL_DETECTOR, reconstruct, content)
@@ -135,11 +138,14 @@ class Compressor(object):
         """Concatenate together a list of files"""
         return '\n'.join([self.read_file(path) for path in paths])
 
-    def construct_asset_path(self, asset_path, css_path, variant=None):
+    def construct_asset_path(self, asset_path, css_path, variant=None,
+                             absolute_asset_paths=True):
         """Return a rewritten asset URL for a stylesheet"""
         public_path = self.absolute_path(asset_path, os.path.dirname(css_path))
         if self.embeddable(public_path, variant):
             return "__EMBED__%s" % public_path
+        if not absolute_asset_paths:
+            return asset_path
         if not os.path.isabs(asset_path):
             asset_path = self.relative_path(public_path)
         asset_url = asset_path.replace(os.sep, '/')
